@@ -17,7 +17,7 @@
  * under the License.
  */
 
-export const canAppendWildcard = (keyPressed) => {
+export const canAppendWildcard = keyPressed => {
   // If it's not a letter, number or is something longer, reject it
   if (!keyPressed || !/[a-z0-9]/i.test(keyPressed) || keyPressed.length !== 1) {
     return false;
