@@ -17,16 +17,21 @@
  * under the License.
  */
 
-export async function importFile(file, FileReader = window.FileReader) {
-  return new Promise((resolve, reject) => {
-    const fr = new FileReader();
-    fr.onload = ({ target: { result } }) => {
-      try {
-        resolve(JSON.parse(result));
-      } catch (e) {
-        reject(e);
-      }
-    };
-    fr.readAsText(file);
+import { kfetch } from 'ui/kfetch';
+
+export async function importFile(file, overwriteAll = false) {
+  const formData = new FormData();
+  formData.append('file', file);
+  return await kfetch({
+    method: 'POST',
+    pathname: '/api/saved_objects/_import',
+    body: formData,
+    headers: {
+      // Important to be undefined, it forces proper headers to be set for FormData
+      'Content-Type': undefined,
+    },
+    query: {
+      overwrite: overwriteAll,
+    },
   });
 }
