@@ -17,14 +17,19 @@
  * under the License.
  */
 
-export * from './get_in_app_url';
+export * from './fetch_export_by_type_and_search';
+export * from './fetch_export_objects';
+export * from './in_app_url';
 export * from './get_relationships';
 export * from './get_saved_object_counts';
-export * from './get_saved_object_icon';
 export * from './get_saved_object_label';
 export * from './import_file';
+export * from './import_legacy_file';
 export * from './parse_query';
+export * from './resolve_import_errors';
 export * from './resolve_saved_objects';
-export * from './retrieve_and_export_docs';
-export * from './save_to_file';
-export * from './scan_all_types';
+export * from './log_legacy_import';
+export * from './process_import_response';
+export * from './get_default_title';
+export * from './find_objects';
+export * from './extract_export_details';
