@@ -19,12 +19,14 @@
 
 import React, { PureComponent, Fragment } from 'react';
 import PropTypes from 'prop-types';
+import { npStart } from 'ui/new_platform';
 
 import 'brace/theme/textmate';
 import 'brace/mode/markdown';
 
 import { toastNotifications } from 'ui/notify';
 import {
+  EuiBadge,
   EuiButton,
   EuiButtonEmpty,
   EuiCode,
@@ -41,23 +43,24 @@ import {
   EuiImage,
   EuiLink,
   EuiSpacer,
+  EuiToolTip,
   EuiText,
   EuiSelect,
   EuiSwitch,
   keyCodes,
 } from '@elastic/eui';
+import { i18n } from '@kbn/i18n';
+import { FormattedMessage } from '@kbn/i18n/react';
 
 import { isDefaultValue } from '../../lib';
 
-import { FormattedMessage, injectI18n } from '@kbn/i18n/react';
-
-class FieldUI extends PureComponent {
-
+export class Field extends PureComponent {
   static propTypes = {
     setting: PropTypes.object.isRequired,
     save: PropTypes.func.isRequired,
     clear: PropTypes.func.isRequired,
-  }
+    enableSaving: PropTypes.bool.isRequired,
+  };
 
   constructor(props) {
     super(props);
@@ -76,19 +79,19 @@ class FieldUI extends PureComponent {
     this.changeImageForm = null;
   }
 
-  componentWillReceiveProps(nextProps) {
+  UNSAFE_componentWillReceiveProps(nextProps) {
     const { unsavedValue } = this.state;
     const { type, value, defVal } = nextProps.setting;
     const editableValue = this.getEditableValue(type, value, defVal);
 
     this.setState({
       savedValue: editableValue,
-      unsavedValue: (value === null || value === undefined) ? editableValue : unsavedValue,
+      unsavedValue: value === null || value === undefined ? editableValue : unsavedValue,
     });
   }
 
   getEditableValue(type, value, defVal) {
-    const val = (value === null || value === undefined) ? defVal : value;
+    const val = value === null || value === undefined ? defVal : value;
     switch (type) {
       case 'array':
         return val.join(', ');
@@ -103,13 +106,15 @@ class FieldUI extends PureComponent {
     }
   }
 
-  getDisplayedDefaultValue(type, defVal) {
+  getDisplayedDefaultValue(type, defVal, optionLabels = {}) {
     if (defVal === undefined || defVal === null || defVal === '') {
       return 'null';
     }
     switch (type) {
       case 'array':
         return defVal.join(', ');
+      case 'select':
+        return optionLabels.hasOwnProperty(defVal) ? optionLabels[defVal] : String(defVal);
       default:
         return String(defVal);
     }
@@ -117,7 +122,7 @@ class FieldUI extends PureComponent {
 
   setLoading(loading) {
     this.setState({
-      loading
+      loading,
     });
   }
 
@@ -128,7 +133,7 @@ class FieldUI extends PureComponent {
     });
   }
 
-  onCodeEditorChange = (value) => {
+  onCodeEditorChange = value => {
     const { type } = this.props.setting;
     const { isJsonArray } = this.state;
 
@@ -147,7 +152,8 @@ class FieldUI extends PureComponent {
             <FormattedMessage
               id="kbn.management.settings.field.codeEditorSyntaxErrorMessage"
               defaultMessage="Invalid JSON syntax"
-            />);
+            />
+          );
         }
         break;
       default:
@@ -159,11 +165,11 @@ class FieldUI extends PureComponent {
       isInvalid,
       unsavedValue: newUnsavedValue,
     });
-  }
+  };
 
-  onFieldChange = (e) => {
+  onFieldChange = e => {
     const value = e.target.value;
-    const { type } = this.props.setting;
+    const { type, validation } = this.props.setting;
     const { unsavedValue } = this.state;
 
     let newUnsavedValue = undefined;
@@ -178,10 +184,23 @@ class FieldUI extends PureComponent {
       default:
         newUnsavedValue = value;
     }
+
+    let isInvalid = false;
+    let error = undefined;
+
+    if (validation && validation.regex) {
+      if (!validation.regex.test(newUnsavedValue)) {
+        error = validation.message;
+        isInvalid = true;
+      }
+    }
+
     this.setState({
       unsavedValue: newUnsavedValue,
+      isInvalid,
+      error,
     });
-  }
+  };
 
   onFieldKeyDown = ({ keyCode }) => {
     if (keyCode === keyCodes.ENTER) {
@@ -190,15 +209,15 @@ class FieldUI extends PureComponent {
     if (keyCode === keyCodes.ESCAPE) {
       this.cancelEdit();
     }
-  }
+  };
 
   onFieldEscape = ({ keyCode }) => {
     if (keyCode === keyCodes.ESCAPE) {
       this.cancelEdit();
     }
-  }
+  };
 
-  onImageChange = async (files) => {
+  onImageChange = async files => {
     if (!files.length) {
       this.clearError();
       this.setState({
@@ -208,32 +227,32 @@ class FieldUI extends PureComponent {
     }
 
     const file = files[0];
-    const { maxSize } = this.props.setting.options;
+    const { maxSize } = this.props.setting.validation;
     try {
       const base64Image = await this.getImageAsBase64(file);
       const isInvalid = !!(maxSize && maxSize.length && base64Image.length > maxSize.length);
       this.setState({
         isInvalid,
         error: isInvalid
-          ? this.props.intl.formattedMessage({
-            id: 'kbn.management.settings.field.imageTooLargeErrorMessage',
-            defaultMessage: 'Image is too large, maximum size is {maxSizeDescription}'
-          }, {
-            maxSizeDescription: maxSize.description
-          }) : null,
+          ? i18n.translate('kbn.management.settings.field.imageTooLargeErrorMessage', {
+              defaultMessage: 'Image is too large, maximum size is {maxSizeDescription}',
+              values: {
+                maxSizeDescription: maxSize.description,
+              },
+            })
+          : null,
         changeImage: true,
         unsavedValue: base64Image,
       });
     } catch (err) {
       toastNotifications.addDanger(
-        this.props.intl.formatMessage({
-          id: 'kbn.management.settings.field.imageChangeErrorMessage',
-          defaultMessage: 'Image could not be saved'
+        i18n.translate('kbn.management.settings.field.imageChangeErrorMessage', {
+          defaultMessage: 'Image could not be saved',
         })
       );
       this.cancelChangeImage();
     }
-  }
+  };
 
   getImageAsBase64(file) {
     if (!file instanceof File) {
@@ -247,7 +266,7 @@ class FieldUI extends PureComponent {
       reader.onload = () => {
         resolve(reader.result);
       };
-      reader.onerror = (err) => {
+      reader.onerror = err => {
         reject(err);
       };
     });
@@ -257,7 +276,7 @@ class FieldUI extends PureComponent {
     this.setState({
       changeImage: true,
     });
-  }
+  };
 
   cancelChangeImage = () => {
     const { savedValue } = this.state;
@@ -271,7 +290,7 @@ class FieldUI extends PureComponent {
       changeImage: false,
       unsavedValue: savedValue,
     });
-  }
+  };
 
   cancelEdit = () => {
     const { savedValue } = this.state;
@@ -279,7 +298,35 @@ class FieldUI extends PureComponent {
     this.setState({
       unsavedValue: savedValue,
     });
-  }
+  };
+
+  showPageReloadToast = () => {
+    if (this.props.setting.requiresPageReload) {
+      toastNotifications.add({
+        title: i18n.translate('kbn.management.settings.field.requiresPageReloadToastDescription', {
+          defaultMessage: 'Please reload the page for the "{settingName}" setting to take effect.',
+          values: {
+            settingName: this.props.setting.displayName || this.props.setting.name,
+          },
+        }),
+        text: (
+          <>
+            <EuiFlexGroup justifyContent="flexEnd" gutterSize="s">
+              <EuiFlexItem grow={false}>
+                <EuiButton size="s" onClick={() => window.location.reload()}>
+                  {i18n.translate(
+                    'kbn.management.settings.field.requiresPageReloadToastButtonLabel',
+                    { defaultMessage: 'Reload page' }
+                  )}
+                </EuiButton>
+              </EuiFlexItem>
+            </EuiFlexGroup>
+          </>
+        ),
+        color: 'success',
+      });
+    }
+  };
 
   saveEdit = async () => {
     const { name, defVal, type } = this.props.setting;
@@ -312,62 +359,63 @@ class FieldUI extends PureComponent {
         await this.props.save(name, valueToSave);
       }
 
+      this.showPageReloadToast();
+
       if (changeImage) {
         this.cancelChangeImage();
       }
     } catch (e) {
       toastNotifications.addDanger(
-        this.props.intl.formatMessage({
-          id: 'kbn.management.settings.field.saveFieldErrorMessage',
-          defaultMessage: 'Unable to save {name}'
-        },
-        { name })
+        i18n.translate('kbn.management.settings.field.saveFieldErrorMessage', {
+          defaultMessage: 'Unable to save {name}',
+          values: { name },
+        })
       );
     }
     this.setLoading(false);
-  }
+  };
 
   resetField = async () => {
     const { name } = this.props.setting;
     this.setLoading(true);
     try {
       await this.props.clear(name);
+      this.showPageReloadToast();
       this.cancelChangeImage();
       this.clearError();
     } catch (e) {
       toastNotifications.addDanger(
-        this.props.intl.formatMessage({
-          id: 'kbn.management.settings.field.resetFieldErrorMessage',
-          defaultMessage: 'Unable to reset {name}'
-        },
-        { name })
+        i18n.translate('kbn.management.settings.field.resetFieldErrorMessage', {
+          defaultMessage: 'Unable to reset {name}',
+          values: { name },
+        })
       );
     }
     this.setLoading(false);
-  }
+  };
 
   renderField(setting) {
+    const { enableSaving } = this.props;
     const { loading, changeImage, unsavedValue } = this.state;
-    const { name, value, type, options, isOverridden, ariaName } = setting;
+    const { name, value, type, options, optionLabels = {}, isOverridden, ariaName } = setting;
 
     switch (type) {
       case 'boolean':
         return (
           <EuiSwitch
-            label={!!unsavedValue ? (
-              <FormattedMessage
-                id="kbn.management.settings.field.onLabel"
-                defaultMessage="On"
-              />
-            ) : (
-              <FormattedMessage
-                id="kbn.management.settings.field.offLabel"
-                defaultMessage="Off"
-              />
-            )}
+            label={
+              !!unsavedValue ? (
+                <FormattedMessage id="kbn.management.settings.field.onLabel" defaultMessage="On" />
+              ) : (
+                <FormattedMessage
+                  id="kbn.management.settings.field.offLabel"
+                  defaultMessage="Off"
+                />
+              )
+            }
             checked={!!unsavedValue}
             onChange={this.onFieldChange}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
             aria-label={ariaName}
@@ -387,35 +435,30 @@ class FieldUI extends PureComponent {
               height="auto"
               minLines={6}
               maxLines={30}
-              isReadOnly={isOverridden}
+              isReadOnly={isOverridden || !enableSaving}
               setOptions={{
                 showLineNumbers: false,
                 tabSize: 2,
               }}
               editorProps={{
-                $blockScrolling: Infinity
+                $blockScrolling: Infinity,
               }}
-
+              showGutter={false}
             />
           </div>
         );
       case 'image':
         if (!isDefaultValue(setting) && !changeImage) {
-          return (
-            <EuiImage
-              aria-label={ariaName}
-              allowFullScreen
-              url={value}
-              alt={name}
-            />
-          );
+          return <EuiImage aria-label={ariaName} allowFullScreen url={value} alt={name} />;
         } else {
           return (
             <EuiFilePicker
-              disabled={loading || isOverridden}
+              disabled={loading || isOverridden || !enableSaving}
               onChange={this.onImageChange}
               accept=".jpg,.jpeg,.png"
-              ref={(input) => { this.changeImageForm = input; }}
+              ref={input => {
+                this.changeImageForm = input;
+              }}
               onKeyDown={this.onFieldEscape}
               data-test-subj={`advancedSetting-editField-${name}`}
             />
@@ -426,12 +469,15 @@ class FieldUI extends PureComponent {
           <EuiSelect
             aria-label={ariaName}
             value={unsavedValue}
-            options={options.map((text) => {
-              return { text, value: text };
+            options={options.map(option => {
+              return {
+                text: optionLabels.hasOwnProperty(option) ? optionLabels[option] : option,
+                value: option,
+              };
             })}
             onChange={this.onFieldChange}
             isLoading={loading}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
           />
@@ -443,7 +489,7 @@ class FieldUI extends PureComponent {
             value={unsavedValue}
             onChange={this.onFieldChange}
             isLoading={loading}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
           />
@@ -455,7 +501,7 @@ class FieldUI extends PureComponent {
             value={unsavedValue}
             onChange={this.onFieldChange}
             isLoading={loading}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
           />
@@ -479,10 +525,11 @@ class FieldUI extends PureComponent {
       );
     }
 
+    const canUpdateSetting = this.props.enableSaving;
     const defaultLink = this.renderResetToDefaultLink(setting);
     const imageLink = this.renderChangeImageLink(setting);
 
-    if (defaultLink || imageLink) {
+    if (canUpdateSetting && (defaultLink || imageLink)) {
       return (
         <span>
           {defaultLink}
@@ -498,26 +545,59 @@ class FieldUI extends PureComponent {
     return (
       <h3>
         {setting.displayName || setting.name}
-        {setting.isCustom ?
+        {setting.isCustom ? (
           <EuiIconTip
             type="asterisk"
             color="primary"
-            aria-label={this.props.intl.formatMessage({
-              id: 'kbn.management.settings.field.customSettingAriaLabel',
+            aria-label={i18n.translate('kbn.management.settings.field.customSettingAriaLabel', {
               defaultMessage: 'Custom setting',
             })}
-            content={(<FormattedMessage
-              id="kbn.management.settings.field.customSettingTooltip"
-              defaultMessage="Custom setting"
-            />)}
+            content={
+              <FormattedMessage
+                id="kbn.management.settings.field.customSettingTooltip"
+                defaultMessage="Custom setting"
+              />
+            }
           />
-          : ''}
+        ) : (
+          ''
+        )}
       </h3>
     );
   }
 
   renderDescription(setting) {
     let description;
+    let deprecation;
+
+    if (setting.deprecation) {
+      const { links } = npStart.core.docLinks;
+
+      deprecation = (
+        <>
+          <EuiToolTip content={setting.deprecation.message}>
+            <EuiBadge
+              color="warning"
+              onClick={() => {
+                window.open(links.management[setting.deprecation.docLinksKey], '_blank');
+              }}
+              onClickAriaLabel={i18n.translate(
+                'kbn.management.settings.field.deprecationClickAreaLabel',
+                {
+                  defaultMessage: 'Click to view deprecation documentation for {settingName}.',
+                  values: {
+                    settingName: setting.name,
+                  },
+                }
+              )}
+            >
+              Deprecated
+            </EuiBadge>
+          </EuiToolTip>
+          <EuiSpacer size="s" />
+        </>
+      );
+    }
 
     if (React.isValidElement(setting.description)) {
       description = setting.description;
@@ -535,6 +615,7 @@ class FieldUI extends PureComponent {
 
     return (
       <Fragment>
+        {deprecation}
         {description}
         {this.renderDefaultValue(setting)}
       </Fragment>
@@ -542,7 +623,7 @@ class FieldUI extends PureComponent {
   }
 
   renderDefaultValue(setting) {
-    const { type, defVal } = setting;
+    const { type, defVal, optionLabels } = setting;
     if (isDefaultValue(setting)) {
       return;
     }
@@ -564,7 +645,7 @@ class FieldUI extends PureComponent {
                     >
                       {this.getDisplayedDefaultValue(type, defVal)}
                     </EuiCodeBlock>
-                  )
+                  ),
                 }}
               />
             </Fragment>
@@ -574,7 +655,9 @@ class FieldUI extends PureComponent {
                 id="kbn.management.settings.field.defaultValueText"
                 defaultMessage="Default: {value}"
                 values={{
-                  value: (<EuiCode>{this.getDisplayedDefaultValue(type, defVal)}</EuiCode>),
+                  value: (
+                    <EuiCode>{this.getDisplayedDefaultValue(type, defVal, optionLabels)}</EuiCode>
+                  ),
                 }}
               />
             </Fragment>
@@ -592,12 +675,11 @@ class FieldUI extends PureComponent {
     return (
       <span>
         <EuiLink
-          aria-label={this.props.intl.formatMessage({
-            id: 'kbn.management.settings.field.resetToDefaultLinkAriaLabel',
+          aria-label={i18n.translate('kbn.management.settings.field.resetToDefaultLinkAriaLabel', {
             defaultMessage: 'Reset {ariaName} to default',
-          },
-          {
-            ariaName,
+            values: {
+              ariaName,
+            },
           })}
           onClick={this.resetField}
           data-test-subj={`advancedSetting-resetField-${name}`}
@@ -621,12 +703,11 @@ class FieldUI extends PureComponent {
     return (
       <span>
         <EuiLink
-          aria-label={this.props.intl.formatMessage({
-            id: 'kbn.management.settings.field.changeImageLinkAriaLabel',
+          aria-label={i18n.translate('kbn.management.settings.field.changeImageLinkAriaLabel', {
             defaultMessage: 'Change {ariaName}',
-          },
-          {
-            ariaName,
+            values: {
+              ariaName,
+            },
           })}
           onClick={this.changeImage}
           data-test-subj={`advancedSetting-changeImage-${name}`}
@@ -644,7 +725,6 @@ class FieldUI extends PureComponent {
     const { ariaName, name } = setting;
     const { loading, isInvalid, changeImage, savedValue, unsavedValue } = this.state;
     const isDisabled = loading || setting.isOverridden;
-    const { intl } = this.props;
 
     if (savedValue === unsavedValue && !changeImage) {
       return;
@@ -656,12 +736,11 @@ class FieldUI extends PureComponent {
           <EuiFlexItem grow={false}>
             <EuiButton
               fill
-              aria-label={intl.formatMessage({
-                id: 'kbn.management.settings.field.saveButtonAriaLabel',
+              aria-label={i18n.translate('kbn.management.settings.field.saveButtonAriaLabel', {
                 defaultMessage: 'Save {ariaName}',
-              },
-              {
-                ariaName,
+                values: {
+                  ariaName,
+                },
               })}
               onClick={this.saveEdit}
               disabled={isDisabled || isInvalid}
@@ -675,14 +754,16 @@ class FieldUI extends PureComponent {
           </EuiFlexItem>
           <EuiFlexItem grow={false}>
             <EuiButtonEmpty
-              aria-label={intl.formatMessage({
-                id: 'kbn.management.settings.field.cancelEditingButtonAriaLabel',
-                defaultMessage: 'Cancel editing {ariaName}',
-              },
-              {
-                ariaName,
-              })}
-              onClick={() => changeImage ? this.cancelChangeImage() : this.cancelEdit()}
+              aria-label={i18n.translate(
+                'kbn.management.settings.field.cancelEditingButtonAriaLabel',
+                {
+                  defaultMessage: 'Cancel editing {ariaName}',
+                  values: {
+                    ariaName,
+                  },
+                }
+              )}
+              onClick={() => (changeImage ? this.cancelChangeImage() : this.cancelEdit())}
               disabled={isDisabled}
               data-test-subj={`advancedSetting-cancelEditField-${name}`}
             >
@@ -716,17 +797,15 @@ class FieldUI extends PureComponent {
               label={this.renderLabel(setting)}
               helpText={this.renderHelpText(setting)}
               describedByIds={[`${setting.name}-aria`]}
+              className="mgtAdvancedSettings__fieldRow"
+              hasChildLabel={setting.type !== 'boolean'}
             >
               {this.renderField(setting)}
             </EuiFormRow>
           </EuiDescribedFormGroup>
         </EuiFlexItem>
-        <EuiFlexItem grow={false}>
-          {this.renderActions(setting)}
-        </EuiFlexItem>
+        <EuiFlexItem grow={false}>{this.renderActions(setting)}</EuiFlexItem>
       </EuiFlexGroup>
     );
   }
 }
-
-export const Field = injectI18n(FieldUI);
