@@ -18,20 +18,15 @@
  */
 
 import React from 'react';
-import {
-  EuiText
-} from '@elastic/eui';
+import { EuiText } from '@elastic/eui';
 import { FormattedMessage } from '@kbn/i18n/react';
 
 export const PageTitle = () => {
   return (
     <EuiText>
       <h1 data-test-subj="managementSettingsTitle">
-        <FormattedMessage
-          id="kbn.management.settings.pageTitle"
-          defaultMessage="Settings"
-        />
+        <FormattedMessage id="kbn.management.settings.pageTitle" defaultMessage="Settings" />
       </h1>
     </EuiText>
   );
-};
\ No newline at end of file
+};
