@@ -18,5 +18,10 @@
  */
 
 export function isDefaultValue(setting) {
-  return (setting.isCustom || setting.value === undefined || setting.value === '' || String(setting.value) === String(setting.defVal));
+  return (
+    setting.isCustom ||
+    setting.value === undefined ||
+    setting.value === '' ||
+    String(setting.value) === String(setting.defVal)
+  );
 }
