@@ -17,22 +17,24 @@
  * under the License.
  */
 
-import 'ui/autoload/styles';
 import chrome from 'ui/chrome';
-import { hashUrl } from 'ui/state_management/state_hashing';
+import { hashUrl } from '../../../../plugins/kibana_utils/public';
 import uiRoutes from 'ui/routes';
+import { fatalError } from 'ui/notify';
 
 uiRoutes.enable();
-uiRoutes
-  .when('/', {
-    resolve: {
-      url: function (AppState, globalState, $window) {
-        const redirectUrl = chrome.getInjected('redirectUrl');
-
-        const hashedUrl = hashUrl([new AppState(), globalState], redirectUrl);
+uiRoutes.when('/', {
+  resolve: {
+    url: function(AppState, globalState, $window) {
+      const redirectUrl = chrome.getInjected('redirectUrl');
+      try {
+        const hashedUrl = hashUrl(redirectUrl);
         const url = chrome.addBasePath(hashedUrl);
 
         $window.location = url;
+      } catch (e) {
+        fatalError(e);
       }
-    }
-  });
+    },
+  },
+});
