@@ -19,7 +19,7 @@
 
 import React from 'react';
 import { render, unmountComponentAtNode } from 'react-dom';
-import { I18nProvider } from '@kbn/i18n/react';
+import { I18nContext } from 'ui/i18n';
 
 import StatusApp from './status_app';
 
@@ -33,13 +33,10 @@ export function renderStatusPage(buildNum, buildSha) {
   }
 
   render(
-    <I18nProvider>
-      <StatusApp
-        buildNum={buildNum}
-        buildSha={buildSha}
-      />
-    </I18nProvider>,
-    node,
+    <I18nContext>
+      <StatusApp buildNum={buildNum} buildSha={buildSha} />
+    </I18nContext>,
+    node
   );
 }
 
