@@ -17,22 +17,17 @@
  * under the License.
  */
 
-import 'ui/autoload/styles';
 import 'ui/i18n';
-import { uiModules } from 'ui/modules';
 import chrome from 'ui/chrome';
+import { npStart } from 'ui/new_platform';
 import { destroyStatusPage, renderStatusPage } from './components/render';
+import template from 'plugins/status_page/status_page.html';
 
-chrome
-  .setRootTemplate(require('plugins/status_page/status_page.html'))
-  .setRootController('ui', function ($scope, buildNum, buildSha) {
-    $scope.$$postDigest(() => {
-      renderStatusPage(buildNum, buildSha.substr(0, 8));
-      $scope.$on('$destroy', destroyStatusPage);
-    });
-  });
+npStart.core.chrome.navLinks.enableForcedAppSwitcherNavigation();
 
-uiModules.get('kibana')
-  .config(function (appSwitcherEnsureNavigationProvider) {
-    appSwitcherEnsureNavigationProvider.forceNavigation(true);
+chrome.setRootTemplate(template).setRootController('ui', function($scope, buildNum, buildSha) {
+  $scope.$$postDigest(() => {
+    renderStatusPage(buildNum, buildSha.substr(0, 8));
+    $scope.$on('$destroy', destroyStatusPage);
   });
+});
