@@ -19,9 +19,7 @@
 
 import template from './timelion_expression_suggestions.html';
 
-const app = require('ui/modules').get('apps/timelion', []);
-
-app.directive('timelionExpressionSuggestions', () => {
+export function TimelionExpressionSuggestions() {
   return {
     restrict: 'E',
     scope: {
@@ -33,9 +31,9 @@ app.directive('timelionExpressionSuggestions', () => {
     },
     replace: true,
     template,
-    link: function (scope) {
+    link: function(scope) {
       // This will prevent the expression input from losing focus.
       scope.onMouseDown = e => e.preventDefault();
-    }
+    },
   };
-});
+}
