@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,6 +18,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+require('symbol-observable');
+
+require('./root');
 
 require('./node_version_validator');
+
 require('./babel_register');
\ No newline at end of file
