@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,8 +18,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 require('../node_modules/leaflet/dist/leaflet.css');
+
 window.L = module.exports = require('../node_modules/leaflet/dist/leaflet');
 window.L.Browser.touch = false;
 window.L.Browser.pointer = false;
@@ -27,7 +27,9 @@ window.L.Browser.pointer = false;
 require('../node_modules/leaflet.heat/dist/leaflet-heat.js');
 
 require('../node_modules/leaflet-draw/dist/leaflet.draw.css');
+
 require('../node_modules/leaflet-draw/dist/leaflet.draw.js');
 
 require('../node_modules/leaflet-responsive-popup/leaflet.responsive.popup.css');
+
 require('../node_modules/leaflet-responsive-popup/leaflet.responsive.popup.js');
\ No newline at end of file
