@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,5 +18,4 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 module.exports = require('@elastic/numeral');
\ No newline at end of file
